#ifndef QDELETENOTESVIEW_H
#define QDELETENOTESVIEW_H

#include <QtGui/QMainWindow>
#include "ui_QDeleteNotesView.h"
#include "QvernoteWindow.h"
#include "QvernoteAPI.h"

using namespace qvernote::api;

class QDeleteNotesView : public QvernoteWindow
{
    Q_OBJECT

public:
    QDeleteNotesView(QvernoteAPI* hEvernote, const QString& notebookName, QWidget *parent = 0);
    ~QDeleteNotesView();

    void loadNotesIntoView();

public slots:
	void setItemMark(QListWidgetItem *item);
	void deleteSelectedNotes();
    void addSelectedCount() { m_lSelectedCount.setText(QString("%1 notes").arg(++m_iSelectedCount)); }
    void subSelectedCount() { m_lSelectedCount.setText(QString("%1 notes").arg(--m_iSelectedCount)); }

private:
    Ui::QDeleteNotesViewClass ui;
    QvernoteAPI* m_hEvernote;
    QString m_notebookName;
    QLabel	m_lSelectedCount;
    QPushButton m_pbDeleteSelected;
    int		m_iSelectedCount;
    QWidget* m_parent;
};

#endif // QDELETENOTESVIEW_H
